# Define if you want to build the sane backend (default)
%define sane_backend		1
%{?_with_sane:			%global sane_backend 1}
%{?_without_sane:		%global sane_backend 0}

%define hpip_major		0
%define hpip_libname		%mklibname hpip %{hpip_major}

%define sane_hpaio_major	1
%define sane_hpaio_libname	%mklibname sane-hpaio %{sane_hpaio_major}

# Suppress automatically generated Requires for devel packages
%global __requires_exclude	devel\\\(.*\\\)

# we don't want to provide private python extension libs
%global __provides_exclude	%{python3_sitearch}/.*\\.so$

#define extraversion -RC1
%define extraversion		%nil

Summary:	HP printer/all-in-one driver infrastructure
Name:		hplip
Version:	3.17.4
Release:	%mkrel 1
License:	GPLv2+ and MIT
Group:		System/Printing
Url:		http://hplipopensource.com/hplip-web/index.html
Source:		http://downloads.sourceforge.net/sourceforge/hplip/%{name}-%{version}%{extraversion}.tar.gz
Source1:	hpcups-update-ppds.sh
Source2:	%{name}-tmpfiles.conf

# (doktor5000) newer automake [>1.13.1] need option subdir-objects if one
# source file is in a subdirectory, build does not complete otherwise
Patch1:		hplip-3.15.11-mga-automake-fix-subdir-objects.patch

# (Anssi) Apply udev rules even on ACTION=="change", otherwise the permissions
# do not get applied in %%post on a new installation:
Patch2:		hplip-apply-udev-rules-on-action-change.patch

# (cjw) HPLIP 3.14.6 set umask to 0 when creating the ~/.hplip directory
#       causing the subsequently created ~/.hplip/hplip.conf to be world-
#       writable. This patch aims to reset the umask after creating the 
#       directory.
# (spuhler) This patch isn't neede anymore (per Chris Velwaart, e-mail of 2015-06-01)
#Patch3:	hplip-3.15.2-no-world-writable-user-config.patch

# Link patch
Patch4:		hplip-3.15.4-hp_ipp.patch

# (akien) Start after panel in Plasma5 (mga#16946)
Patch5:		hplip-3.15.11-mga-plasma-delay-startup.patch

# Fedora patches
Patch101:	hplip-pstotiff-is-rubbish.patch
Patch102:	hplip-strstr-const.patch
Patch104:	hplip-no-asm.patch
Patch107:	hplip-udev-rules.patch 
Patch108:	hplip-retry-open.patch
Patch109:	hplip-snmp-quirks.patch

Patch111:	hplip-hpijs-marker-supply.patch
Patch112:	hplip-clear-old-state-reasons.patch
Patch114:	hplip-hpcups-sigpipe.patch
Patch115:	hplip-logdir.patch
Patch116:	hplip-bad-low-ink-warning.patch
Patch121:	hplip-ppd-ImageableArea.patch


# Debian/Ubuntu patches
# taken from latest version at http://patch-tracker.debian.org/package/hplip
Patch201:	01_rss.dpatch
Patch203:	14_charsign_fixes.dpatch
# (doktor5000) rediff original debian patch for hplip 3.13.2 (due to Patch1)
Patch204:	hplip-3.15.11-mga-85_rebuild_python_ui.dpatch
# (doktor5000) rediff original debian patch for hplip 3.12.4

Patch206:	hplip-photosmart_b9100_support.patch
Patch207:	hplip-pjl-duplex-binding.patch
# user should be member of group "lp" to scan/print/fax and lpadmin to manage?
# check comment above patch application, currently not applied
#Patch215:	simple-scan-as-default.dpatch
Patch219:	try_libhpmud.so.0.dpatch
Patch220:	add-lidil-two-cartridge-modes.dpatch
Patch222:	hp-plugin-download-fix.dpatch
Patch223:	install-check-plugin.diff
Patch224:	pcardext-python3-workaround-upstream.dpatch
Patch225:	hpfax-bug-function-used-before-importing-log.dpatch
Patch226:	hp-systray-make-menu-title-visible-in-sni-qt-indicator.dpatch
Patch227:	hp-systray-make-menu-appear-in-sni-qt-indicator-with-kde.dpatch
Patch228:	hpaio-option-duplex.diff
Patch229:	ui-patch-upstream-like.dpatch

Patch300:	add-mga-support.patch

%if %{sane_backend}
BuildRequires:	libsane-devel
BuildRequires:	xsane
%endif
BuildRequires:	python3
BuildRequires:	python3-sip >= 4.1.1
BuildRequires:	python3-qt5-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	net-snmp-devel
BuildRequires:	pkgconfig(libusb) >= 0.1.8
BuildRequires:	imagemagick
BuildRequires:	autoconf
BuildRequires:	libcups-devel
BuildRequires:	libjpeg-devel
BuildRequires:	desktop-file-utils
BuildRequires:	libdbus-devel
BuildRequires:	udev-devel
BuildRequires:	polkit
BuildRequires:	gphoto2-devel
BuildRequires:	libv4l-devel
# Make sure we get postscriptdriver tags:
BuildRequires:	python3-cups
Requires(post):	systemd >= %{systemd_required_version}
Requires:	cups
# For dynamic ppd generation.
Requires:	foomatic-filters
Requires:	hplip-model-data
Requires:	hplip-hpijs
Requires:	hplip-hpijs-ppds
Requires:	python3-sip >= 4.1.1
# Needed for communicating with ethernet-connected printers
Requires:	net-snmp-mibs
# Needed to generate fax cover pages
Requires:	python3-reportlab
# Needed since 2.8.4 for IPC
Requires:	python3-dbus
Requires:	polkit-agent
Requires:	python3-gobject3
# Required by hp-scan for command line scanning
Requires:	python3-pillow
Requires:	sane-backends-hpaio
# Needed to avoid misleading errors about network connectivity (RH bug #705843)
Requires:	wget
# (cg) needed by at least hp-check
Requires:	acl
# (doktor5000) lsusb is required for hp-check
Requires:	usbutils

%description
This is the HP driver package to supply Linux support for most
Hewlett-Packard DeskJet, LaserJet, PSC, OfficeJet, and PhotoSmart
printers and all-in-one peripherals (also known as Multi-Function
Peripherals or MFPs), which can print, scan, copy, fax, and/or access
flash memory cards.

It is work in progress, but printing, scanning, memory card access,
ink/toner/battery/consumable level checking, and inkjet printer
maintenance are supported on most models, when either connected to the
USB or LAN (built-in interfaces or selected HP JetDirect models) on a
Linux workstation with CUPS printing system.

For status and consumable checking and also for inkjet maintenance
there is the graphical tool "hp-toolbox" available (Menu:
"System"/"Monitoring"/"HP Printer Toolbox").

#----------------------------------------------------

%package -n	%{hpip_libname}
Summary:	Dynamic library for the "hplip" HP printer/all-in-one drivers
Group:		System/Printing

%description -n	%{hpip_libname}
Library needed for the "hplip" HP printer/all-in-one drivers.

#----------------------------------------------------

%package -n	%{hpip_libname}-devel
Summary:	Headers and links to compile against the "%{hpip_libname}" ("hplip") library
Group:		Development/C
Requires:	%{hpip_libname} >= %{version}-%{release}
Provides:	libhpip-devel = %{version}-%{release}

%description -n	%{hpip_libname}-devel
This package contains all files which one needs to compile programs using
the "%{hpip_libname}" library.

#----------------------------------------------------

%if %{sane_backend}
%package -n	%{sane_hpaio_libname}
Summary:	SANE driver for scanners in HP's multi-function devices (from HPLIP)
Group:		System/Printing
Requires:	sane-backends
Provides:	sane-backends-hpaio = %{version}-%{release}
# (cjw) for system-config-printer
Provides:	libsane-hpaio
%global __requires_exclude devel\\(libcrypto\\)|devel\\(libdl\\)|devel\\(libhpip\\)|devel\\(libm\\)|devel\\(libsnmp\\)
%endif

%if %{sane_backend}
%description -n	%{sane_hpaio_libname}
SANE driver for scanners in HP's multi-function devices (from HPLIP).
%endif

#----------------------------------------------------

%if 0
%if %{sane_backend}
%package -n	%{sane_hpaio_libname}-devel
Summary:	Headers and links to compile against the "%{sane_hpaio_libname}" ("sane-hpaio") library
Group:		Development/C
Requires:	%{sane_hpaio_libname} >= %{version}-%{release}
Provides:	libsane-hpaio-devel = %{version}-%{release}
%endif

%if %{sane_backend}
%description -n	%{sane_hpaio_libname}-devel
This package contains all files which one needs to compile programs using
the "%{sane_hpaio_libname}" library.
%endif
%endif
#----------------------------------------------------

%package	model-data
Summary:	Data file listing the HP printer models supported by HPLIP
Group:		System/Printing

%description	model-data
HPLIP supports most current HP printers and multifunction devices, but
there are some older models not supported. This package contains the
list of supported models. Printerdrake installs it automatically to
determine whether HPLIP has to be installed or not.

#----------------------------------------------------

%package	gui
Summary:	HPLIP graphical tools
Group:		System/Printing
Requires:	python3-qt5-core
Requires:	python3-qt5-dbus
Requires:	python3-qt5-gui
Requires:	python3-qt5-widgets
Requires:	%{name} = %{version}-%{release}
Requires:	polkit-agent

%description	gui
HPLIP graphical tools.

#----------------------------------------------------

%package	hpijs
Summary:	HPs printer driver IJS plug-in for GhostScript
Group:		System/Printing
Requires:	ghostscript
Provides:	hpijs

%description	hpijs
HPs printer driver IJS plug-in for GhostScript. This driver gives full
printing support for nearly all non-PostScript inkjet and laser
printers made by HP.

#----------------------------------------------------

%package	hpijs-ppds
Summary:	PPD files for the HPIJS printer driver
Group:		System/Printing
Requires:	foomatic-filters
Requires:	hplip-hpijs

%description	hpijs-ppds
PPD files to use the HPIJS printer driver with foomatic-rip and a
printer spooler like CUPS, LPRng, PDQ, ...

#----------------------------------------------------

%package	doc
Summary:	Documentation for HPLIP
Group:		System/Printing

%description	doc
This package contains documentation for the HPLIP driver.

This is the HP driver package to supply Linux support for most
Hewlett-Packard DeskJet, LaserJet, PSC, OfficeJet, and PhotoSmart
printers and all-in-one peripherals (also known as Multi-Function
Peripherals or MFPs), which can print, scan, copy, fax, and/or access
flash memory cards.

#----------------------------------------------------

%prep
rm -rf $RPM_BUILD_DIR/%{name}-%{version}%{extraversion}
%setup -q -n %{name}-%{version}%{extraversion}

%patch1 -p1 -b .automake-subdir-objects

%patch2 -p1 -b .udev-rules-on-action-change

#%%patch3 -p1 -b .umask

%patch4 -p1 -b .hp_ipp

### Fedora patches

# The pstotiff filter is rubbish so replace it (launchpad #528394).
%patch101 -p1 -b .pstotiff-is-rubbish

# Fix compilation.
%patch102 -p1 -b .strstr-const

# Make sure to avoid handwritten asm.
%patch104 -p1 -b .no-asm

# Removed SYSFS use in udev rules and actually made them work (bug #560754).
# Move udev rules to /lib/udev/rules.d (bug #748208).
%patch107 -p1 -b .udev-rules

# Retry when connecting to device fails (RH bug #532112).
%patch108 -p1 -b .retry-open

# Mark SNMP quirks in PPD for HP OfficeJet Pro 8500 (RH bug #581825).
%patch109 -p1 -b .snmp-quirks

# Fixed bogus low ink warnings from hpijs driver (RH bug #643643).
%patch111 -p1 -b .hpijs-marker-supply

# Clear old printer-state-reasons we used to manage (RH bug #510926).
%patch112 -p1 -b .clear-old-state-reasons

# Avoid busy loop in hpcups when backend has exited (RH bug #525944).
%patch114 -p1 -b .hpcups-sigpipe

# CUPS filters should use TMPDIR when available (bug #865603).
%patch115 -p1 -b .logdir

# Fixed Device ID parsing code in hpijs's dj9xxvip.c (RH bug #510926).
%patch116 -p1 -b .bad-low-ink-warning

# Fix ImageableArea for Laserjet 8150/9000 (RH bug #596298).
for ppd_file in $(grep '^diff' %{PATCH121} | cut -d " " -f 4);
do
  gunzip ${ppd_file#*/}.gz
done
%patch121 -p1 -b .ImageableArea
for ppd_file in $(grep '^diff' %{PATCH121} | cut -d " " -f 4);
do
  gzip -n ${ppd_file#*/}
done

# Don't run 'chgrp lp /var/log/hp' in makefile (removes all lines with "chgrp")
sed -i '/chgrp/d' Makefile.am

sed -i.duplex-constraints \
    -e 's,\(UIConstraints.* \*Duplex\),//\1,' \
    prnt/drv/hpcups.drv.in


### Debian/Ubuntu patches

# This patch tries to make sure that black is printed with just
# the black pen, if the printer supports it
%patch201 -p1 -b .01_rss

# code cleanup related to char signedness
%patch203 -p1 -b .14_charsign

# compiling ui files to py
%patch204 -p1 -b .85_rebuild_python_ui

# Corrections on the models.dat entry for the HP PhotoSmart Pro B9100,
# especially for the correct color calibration mode.
%patch206 -p1 -b .hplip-photosmart_b9100_support

# Fixes Short-edge duplex printing if duplex is PJL-controlled
# https://bugs.launchpad.net/hplip/+bug/244295
%patch207 -p1 -b .hplip-pjl-duplex-binding

# disable for now, as this changes default hplip behavior
# and change in default scanning application should be decided by a poll first
#%%patch215 -p1 -b .simple-scan-as-default

# dlopen libhpmud.so.0 instad of libhpmud.so, in order not to depend on
# devel package (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=548379)
# obsoletes hplip-3.9.8-dlopen-libhpmud.patch, newer & extended version
%patch219 -p1 -b .try_libhpmud.so.0

%patch220 -p1 -b .add-lidil-two-cartridge-modes

%patch222 -p1 -b .plugin-download

%patch223 -p1 -b .install-check-plugin

%patch224 -p1 -b .pcardext-python3-workaround

%patch225 -p1 -b .hpfax-bug-function-used-before-importing-log

%patch226 -p1 -b .hp-systray-make-menu-title-visible-in-sni-qt-indicator

%patch227 -p1 -b .hp-systray-make-menu-appear-in-sni-qt-indicator-with-kde

%patch228 -p1 -b .hpaio-option-duplex

%patch229 -p1 -b .ui-patch-upstream-like


### Mageia patches
%patch300 -p1

# Use filter foomatic-rip instead of foomatic-rip-hplip (fix from Mandriva)
for PPDGZ in ppd/hpijs/*.ppd.gz
do
mv -T "$PPDGZ" "$PPDGZ.old"
zcat "$PPDGZ.old" | sed -e 's/foomatic-rip-hplip/foomatic-rip/' | gzip -c > "$PPDGZ"
rm -f "$PPDGZ.old"
done

# Make all files in the source user-writable
chmod -R u+w .

# Correct Python interpreter path in all executables /usr/bin/env python -> /usr/bin/python
find -name '*.py' -print0 | xargs -0 \
    sed -i -e 's,^#!/usr/bin/env python,#!%{__python},'
# "Upgrade" Python interpreter path to Python3 /usr/bin/python -> /usr/bin/python3
find -name '*.py' -print0 | xargs -0 \
    sed -i -e 's,^#!%{__python},#!%{__python3},'
sed -i -e 's,^#!/usr/bin/env python,#!%{__python3},' \
    prnt/filters/hpps

%build
%serverbuild
# create required files as placeholder, otherwise autoreconf fails
touch NEWS README AUTHORS ChangeLog
#needed by patches 204 and 205
autoreconf -ifv


%if !%{sane_backend}
WITHOUT_SANE="--without-sane"
%endif
%configure2_5x $WITHOUT_SANE \
	--disable-foomatic-rip-hplip-install \
	--enable-scan-build \
	--enable-gui-build \
	--enable-fax-build \
	--enable-pp-build \
	--enable-qt5 --disable-qt4 \
	--enable-hpcups-install \
	--enable-cups-drv-install \
	--enable-cups-ppd-install \
	--enable-hpijs-install \
	--enable-policykit \
	--with-mimedir=%{_datadir}/cups/mime \
	PYTHON=%{__python3}

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_initrddir}
mkdir -p %{buildroot}%{_sysconfdir}/hp

%make_install

# Install files which the "make install" missed to install
install -m 644 ip/hpip.h %{buildroot}%{_includedir}
install -m 644 ip/xform.h %{buildroot}%{_includedir}

# Move doc in sub-package
mv %{buildroot}%{_docdir}/%{name}-%{version}%{extraversion} %{buildroot}%{_docdir}/%{name}-doc-%{version}%{extraversion}

# Remove static libraries of SANE driver
rm -f %{buildroot}%{_libdir}/sane/libsane-hpaio*.so
rm -f %{buildroot}%{_libdir}/sane/libsane-hpaio*.la
rm -f %{buildroot}%{_sysconfdir}/sane.d/dll.conf

# Remove other unneeded/unwanted files
rm -f %{buildroot}%{_datadir}/hplip/uninstall.*
rm -f %{buildroot}%{_bindir}/hp-uninstall
# remove all upgrade-dialog files, also related to CVE-2013-6427
# previously we only removed the upgrade binary, but missed some upgrade dialog files
rm -f %{buildroot}%{_datadir}/hplip/upgrade*
rm -f %{buildroot}%{_bindir}/hp-upgrade
rm -f %{buildroot}%{_bindir}/hp-config_usb_printer
rm -f %{buildroot}%{_unitdir}/hplip-printer@.service
rm -f %{buildroot}%{_datadir}/hplip/config_usb_printer.*

mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install --vendor='' \
	--dir=%{buildroot}%{_datadir}/applications \
	--remove-category='Application' \
	--remove-category='Utility' \
	--add-category='System' \
	--add-category='Settings' \
	--add-category='Printing' \
	--add-category='Qt' \
	--add-category='HardwareSettings' \
	--remove-key='Version' \
	%{buildroot}%{_datadir}/applications/hplip.desktop

cat > %{buildroot}%{_datadir}/applications/hp-sendfax.desktop << EOF
[Desktop Entry]
Name=HP Sendfax
Name[br]=Kas ur faks (HP)
Name[ru]=Отправка факсов (HP)
Name[zh_CN]=惠普发送传真
GenericName=Sending faxes (HP)
GenericName[bg]=Изпращане на факсове (HP)
GenericName[ca]=Enviant faxos (HP)
GenericName[el]=Αποστολή φαξ (HP)
GenericName[es]=Enviando faxes (HP)
GenericName[hu]=Faxok küldése (HP)
GenericName[it]=Inviare i fax (HP)
GenericName[pl]=Wysyłanie faksu (HP)
GenericName[ru]=Отправка факсов (МФУ HP)
GenericName[sq]=Dërgim faksesh (HP)
GenericName[sv]=Sändning av fax (HP)
Comment=Utility for sending faxes with HP's multi-function devices
Comment[bs]=Alat za slanje faksova putem HPovih višefunkcijskih uređaja
Comment[cs]=Pomocný program pro posílání faxů pomocí multifunkčních zařízení HP
Comment[cy]=Gwasanaeth anfon ffacs drwy ddyfeisiau amlbwrpas HP
Comment[de]=Werkzeug um Faxe mit HP-Multifunktionsgeräten zu versenden
Comment[et]=Tööriist fakside saatmiseks HP multifunktsionaalsetest seadmetest
Comment[gl]=Utilidade para enviar faxes cos dispositivos multifunción de HP
Comment[he]=יישום למשלוח פקסים עם מכשירים משולבים של HP
Comment[hu]=Faxküldés a HP-féle többfunkciós eszközökkel
Comment[id]=Utilitas untuk mengirimkan fax dengan divais multi fungsi HP
Comment[is]=Forrit til að senda fax með fjölnotatækjum HP
Comment[it]=Strumento per inviare fax con i dispositivi HP multi-funzione
Comment[ja]=HP の多機能デバイスで FAX を送信するためのユーティリティ
Comment[mk]=Алатка за праќање факсови со повеќе-функциски „HP“ уреди
Comment[nb]=Verktøy for å sende fakser med HPs multifunksjonsenheter
Comment[nl]=Hulpprogramma voor het sturen van faxen met HP multifunctionele apparaten
Comment[nn]=Verktøy for sending av faksar med HPs multifunksjonseiningar
Comment[pl]=Program do wysyłania faksów przez wielofunkcyjne urządzenia HP
Comment[pt]=Utilitário para enviar faxes com dispositivos multi-funções HP
Comment[pt_BR]=Utilitário para enviar faxes com multifuncionais HP
Comment[ru]=Утилита для отправки факсов с помощью МФУ HP
Comment[sl]=Program za pošiljanje faksov z večnamensko napravo HP
Comment[sv]=Verktyg för att skicka fax med HPs multi-funktions-enheter
Comment[tr]=HP'nin çok fonksiyonlu aygıtlarıyla faks göndermek için yardımcı program
Comment[zh_CN]=使用惠普多功能一体机发送传真的工具
Comment[zh_TW]=使用 HP 多功能設備發送傳真的工具程式
Exec=%{_bindir}/hp-sendfax
Icon=%{_datadir}/%{name}/data/images/32x32/fax_machine.png
Terminal=false
Type=Application
Categories=TelephonyTools;Qt;Printing;Utility;X-Mageia-CrossDesktop;
EOF

# tmpfiles.d for folders on transient media
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# (cg) Correct the udev rules dir
mkdir -p %{buildroot}%{_prefix}/lib
mv %{buildroot}%{_sysconfdir}/udev %{buildroot}%{_prefix}/lib/

# switched to udev, no need for hal information
rm -rf  %{buildroot}%{_datadir}/hal/fdi 

rm -f   %{buildroot}%{_libdir}/*.la \
        %{buildroot}%{python3_sitearch}/*.la \
        %{buildroot}%{_libdir}/sane/*.la

# Regenerate hpcups PPDs on upgrade if necessary (bug #579355).
install -p -m755 %{SOURCE1} %{buildroot}%{_bindir}/hpcups-update-ppds

# Fedora pstotiff
rm -f %{buildroot}%{_sysconfdir}/cups/pstotiff.types
rm -f %{buildroot}%{_datadir}/cups/mime/pstotiff.types
rm -f %{buildroot}%{_datadir}/hplip/fax/pstotiff*
rm -f %{buildroot}%{_prefix}/lib/cups/filter/hpcac

# bork?
install -d %{buildroot}%{_sysconfdir}/cups
cp -p %{buildroot}%{_datadir}/cups/mime/pstotiff.convs %{buildroot}%{_sysconfdir}/cups/pstotiff.convs

# (cg) Create post consolehelper compatibility links
mkdir -p %{buildroot}%{_sbindir}
ln -sf %{_bindir}/hp-setup %{buildroot}%{_sbindir}

# Make sure pyc files are generated, otherwise we can get
# difficult to debug problems
pushd %{buildroot}%{_datadir}/%{name}
python -m compileall .
popd

# create empty /var/lip/hp/hplip.state to fix hp-plugin installation (mga#5395)
mkdir -p %{buildroot}%{_localstatedir}/lib/hp/
touch %{buildroot}%{_localstatedir}/lib/hp/hplip.state

# create empty log directory so that it can be owned
mkdir -p %{buildroot}%{_localstatedir}/log/hp/tmp


# Restart CUPS to make the Fax PPD known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%post
%_tmpfilescreate %{name}

%post -n hplip-hpijs-ppds
# Restart CUPS to make the printing PPDs known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%post -n hplip-hpijs
%{_bindir}/hpcups-update-ppds &>/dev/null ||:

%post -n hplip-model-data
/sbin/udevadm trigger --subsystem-match=usb --attr-match=idVendor=03f0
# ensure permissions are ready when installation completes
/sbin/udevadm settle --timeout=15
:

%if %{sane_backend}
%post -n %{sane_hpaio_libname}

# Add HPLIP driver to /etc/sane.d/dll.conf
if ! grep ^hpaio /etc/sane.d/dll.conf >/dev/null 2>/dev/null ; then \
	echo hpaio >> /etc/sane.d/dll.conf; \
fi
%endif

%if %{sane_backend}
%preun -n %{sane_hpaio_libname}
# Remove HPLIP driver from /etc/sane.d/dll.conf
if [ "$1" = 0 ]; then \
	if grep ^hpaio /etc/sane.d/dll.conf >/dev/null 2>/dev/null ; then \
		sed '/hpaio/d' /etc/sane.d/dll.conf > /tmp/$$; \
		cp -f /tmp/$$ /etc/sane.d/dll.conf; \
		rm -f /tmp/$$; \
	fi; \
fi
%endif

# Restart CUPS to make the removal of the Fax PPD known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%postun -n hplip-hpijs-ppds
# Restart CUPS to make the removal of the printing PPDs known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%files
#doc COPYING doc/*
%config(noreplace) %{_sysconfdir}/hp
%dir %{_localstatedir}/lib/hp/
%{_bindir}/hp-align
%{_bindir}/hp-clean
%{_bindir}/hp-colorcal
%{_bindir}/hp-devicesettings
%{_bindir}/hp-diagnose_plugin
%{_bindir}/hp-diagnose_queues
%{_bindir}/hp-doctor
%{_bindir}/hp-fab
%{_bindir}/hp-faxsetup
%{_bindir}/hp-firmware
%{_bindir}/hp-info
%{_bindir}/hp-levels
%{_bindir}/hp-logcapture
%{_bindir}/hp-linefeedcal
%{_bindir}/hp-makecopies
%{_bindir}/hp-makeuri
%{_bindir}/hp-pkservice
%{_bindir}/hp-plugin
%{_bindir}/hp-pqdiag
%{_bindir}/hp-printsettings
%{_bindir}/hp-probe
%{_bindir}/hp-query
%{_bindir}/hp-scan
%{_bindir}/hp-sendfax
%{_bindir}/hp-setup
%{_sbindir}/hp-setup
%{_bindir}/hp-testpage
%{_bindir}/hp-timedate
%{_bindir}/hp-unload
%{_bindir}/hp-wificonfig

%exclude %{_datadir}/hplip/data/models
# C libraries for Python
%{python3_sitearch}/*.so*
# CUPS backends (0755 permissions, so that CUPS 1.2 runs these backends
# as lp user)
# Note: this must be /usr/lib not %%{_libdir}, since that's the
# CUPS serverbin directory.
%attr(0755,root,root) %{_prefix}/lib/cups/backend/hp*
%{_prefix}/lib/cups/filter/hpcups
%{_prefix}/lib/cups/filter/hpcupsfax
%{_prefix}/lib/cups/filter/hpps
%{_prefix}/lib/cups/filter/pstotiff
%{_datadir}/cups/mime/pstotiff.convs
%config(noreplace) %{_sysconfdir}/cups/pstotiff.convs
%{_datadir}/ppd/HP/HP-Fax*.ppd*
%{_datadir}/cups/drv/hp/hpcups.drv
# Files
%dir %{_datadir}/hplip
%{_datadir}/hplip/align.py*
%{_datadir}/hplip/check-plugin.py*
%{_datadir}/hplip/clean.py*
%{_datadir}/hplip/colorcal.py*
%{_datadir}/hplip/devicesettings.py*
%{_datadir}/hplip/diagnose_plugin.py*
%{_datadir}/hplip/diagnose_queues.py*
%{_datadir}/hplip/doctor.py*
%{_datadir}/hplip/fab.py*
%{_datadir}/hplip/fax
%{_datadir}/hplip/faxsetup.py*
%{_datadir}/hplip/firmware.py*
%{_datadir}/hplip/hpdio.py*
%{_datadir}/hplip/hplip_clean.sh
%{_datadir}/hplip/hpssd*
%{_datadir}/hplip/info.py*
%{_datadir}/hplip/__init__.py*
%{_datadir}/hplip/levels.py*
%{_datadir}/hplip/logcapture.py*
%{_datadir}/hplip/linefeedcal.py*
%{_datadir}/hplip/makecopies.py*
%{_datadir}/hplip/makeuri.py*
%{_datadir}/hplip/pkservice.py*
%{_datadir}/hplip/plugin.py*
%{_datadir}/hplip/pqdiag.py*
%{_datadir}/hplip/printsettings.py*
%{_datadir}/hplip/probe.py*
%{_datadir}/hplip/query.py*
%{_datadir}/hplip/scan.py*
%{_datadir}/hplip/sendfax.py*
%{_datadir}/hplip/setup.py*
%{_datadir}/hplip/testpage.py*
%{_datadir}/hplip/timedate.py*
%{_datadir}/hplip/unload.py*
%{_datadir}/hplip/wificonfig.py*
# Directories
%{_datadir}/hplip/base
%{_datadir}/hplip/copier
%dir %{_datadir}/hplip/data
%{_datadir}/hplip/data/ldl
%{_datadir}/hplip/data/localization
%{_datadir}/hplip/data/models
%{_datadir}/hplip/data/pcl
%{_datadir}/hplip/data/ps
%{_datadir}/hplip/installer
%{_datadir}/hplip/pcard
%{_datadir}/hplip/prnt
%{_datadir}/hplip/scan
%{_datadir}/polkit-1/actions/com.hp.hplip.policy
%{_datadir}/dbus-1/system-services/com.hp.hplip.service
%{_tmpfilesdir}/%{name}.conf
%{_localstatedir}/lib/hp/hplip.state
%dir %attr(0774,root,lp) %{_logdir}/hp
%dir %attr(1774,root,lp) %{_logdir}/hp/tmp
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/com.hp.hplip.conf

%files doc
%doc %{_docdir}/%{name}-doc-%{version}%{extraversion}

%files -n %{hpip_libname}
%{_libdir}/libhpip*.so.*
%{_libdir}/libhpmud.so.*
%{_libdir}/libhpdiscovery.so*

%files -n %{hpip_libname}-devel
%{_includedir}/hpip.h
%{_includedir}/xform.h
%{_libdir}/libhpip*.so
%{_libdir}/libhpmud.so

%if %{sane_backend}

%files -n %{sane_hpaio_libname}
%{_libdir}/sane/libsane-hpaio*.so.*

%endif

%files model-data
%{_udevrulesdir}/*.rules
%{_datadir}/hplip/data/models

%files gui
%{_bindir}/hp-check
%{_bindir}/hp-check-plugin
%{_bindir}/hp-print
%{_bindir}/hp-systray
%{_bindir}/hp-toolbox
%{_datadir}/applications/*.desktop
%{_sysconfdir}/xdg/autostart/hplip-systray.desktop
%{_datadir}/hplip/check.py*
%{_datadir}/hplip/print.py*
%{_datadir}/hplip/systray.py*
%{_datadir}/hplip/toolbox.py*
%{_datadir}/hplip/data/images
%{_datadir}/hplip/ui5

%files hpijs
%{_bindir}/hpijs
# Needed for both printing and fax PPDs. They all need HPIJS, therefore
# the link is here
%dir %{_datadir}/ppd
%dir %{_datadir}/ppd/HP
%{_bindir}/hpcups-update-ppds

%files hpijs-ppds
%{_datadir}/ppd/HP/apollo*.ppd*
%{_datadir}/ppd/HP/hp-*.ppd*


%changelog
* Mon May 01 2017 luigiwalser <luigiwalser> 3.17.4-1.mga6
+ Revision: 1098164
- 3.17.4

* Sat Apr 29 2017 martinw <martinw> 3.16.11-3.mga6
+ Revision: 1098048
- fix error in rediff of hplip-apply-udev-rules-on-action-change.patch
  o introduced in r822905, prevents HP device manager communicating
    with printer unless user is in the lp group (mga#18992)

* Fri Mar 10 2017 akien <akien> 3.16.11-2.mga6
+ Revision: 1091607
- Rebuild for v4l-utils 1.12.3

* Sun Jan 01 2017 luigiwalser <luigiwalser> 3.16.11-1.mga6
+ Revision: 1078958
- 3.16.11

* Fri Nov 04 2016 luigiwalser <luigiwalser> 3.16.10-1.mga6
+ Revision: 1065336
- 3.16.10
- remove patch 222 (fixed upstream)

  + daviddavid <daviddavid>
    - fix desktop file Categories (mga#2449)

* Thu Oct 06 2016 daviddavid <daviddavid> 3.16.9-2.mga6
+ Revision: 1059211
- add some more debian patches (especially for a better python3 port)
- rebase some patches with debian's one
- fix some more Python 3 interpreter path in executables (fixes hp-doctor)
- install check-plugin.py as a script
- add BR python3-qt5-devel for pyuic5

* Tue Oct 04 2016 luigiwalser <luigiwalser> 3.16.9-1.mga6
+ Revision: 1058683
- 3.16.9

* Sat Sep 24 2016 daviddavid <daviddavid> 3.16.8-3.mga6
+ Revision: 1055636
- port to python3 + PyQt5

* Thu Sep 22 2016 daviddavid <daviddavid> 3.16.8-2.mga6
+ Revision: 1055142
- add patch to fix build against cups 2.2

* Wed Sep 07 2016 luigiwalser <luigiwalser> 3.16.8-1.mga6
+ Revision: 1050401
- 3.16.8
- add patch from fedora to fix regression in 3.16.8 (rhbz#1372343)

* Thu Aug 11 2016 luigiwalser <luigiwalser> 3.16.7-1.mga6
+ Revision: 1045641
- 3.16.7
- rediff patch 107

* Mon Jun 27 2016 akien <akien> 3.16.5-3.mga6
+ Revision: 1037844
- Rebuild in core/release

* Sat Jun 25 2016 akien <akien> 3.16.5-2.mga6
+ Revision: 1037512
- Rebuild for python-sip 4.18

* Mon May 09 2016 luigiwalser <luigiwalser> 3.16.5-1.mga6
+ Revision: 1011418
- 3.16.5

* Fri Feb 26 2016 tv <tv> 3.16.2-2.mga6
+ Revision: 979664
- patch 300: add support for Mageia

* Fri Feb 26 2016 tv <tv> 3.16.2-1.mga6
+ Revision: 979553
- new release

* Sat Jan 23 2016 akien <akien> 3.15.11-2.mga6
+ Revision: 926656
- Start hplip-systray only after panel in plasma5 (mga#16946)

  + spuhler <spuhler>
    - reversed latch change. Test shows, patch3 isn't needed anymore
    - adding patch3 back to resolve bug 14600 and 15266#c58

* Sat Nov 28 2015 spuhler <spuhler> 3.15.11-1.mga6
+ Revision: 906898
- rediffed some patches.
- added new files %%{_libdir}/libhpdiscovery.so* to lib
- some clean-up
- upgrade to vers. 3.15.11
  * adding a lot of new printers

  + alexl <alexl>
    - add GenericName with translations for hp-sendfax.desktop

* Sun Jul 26 2015 blino <blino> 3.15.7-1.mga6
+ Revision: 857780
- 3.15.7

* Mon Jun 15 2015 spuhler <spuhler> 3.15.6-1.mga6
+ Revision: 823150
- upgrade to vers. 3.15.6
  * support for new printers
- uncommented Patch219
- updated hplip-udev-rules.patch (Patch107) from Fedora
- rediffed try_libhpmud.so.0.dpatch
- upgrade to vers. 3.15.4
  * support for new HP printers
- fixes bug #15266
- removed Fedora Patch110: hplip-discovery-method.patch, they dropped it
- commented out try_libhpmud.so.0.dpatch. The files it was suppoded to patch have changed
- rediffed several patches
 -removed obsolet patch3 per Christian Welvaart dev@ml.mageia.org e-mail of June1, 2015

* Fri Nov 21 2014 alexl <alexl> 3.14.6-8.mga5
+ Revision: 798184
- translate Name for hp-sendfax.desktop (merge with Mandrake)

* Fri Nov 21 2014 cjw <cjw> 3.14.6-7.mga5
+ Revision: 798079
- patch3: reset umask after creating ~/.hplip/ so ~/.hplip/hplip.conf is not created with world-writable permissions (fixes #14600)

* Wed Nov 19 2014 alexl <alexl> 3.14.6-6.mga5
+ Revision: 797838
- s/Mandriva/Mageia/
- translated hp-sendfax.desktop

* Thu Nov 13 2014 tv <tv> 3.14.6-5.mga5
+ Revision: 796728
- BR python-cups so that we got postscriptdriver provides

* Wed Oct 15 2014 umeabot <umeabot> 3.14.6-4.mga5
+ Revision: 741495
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 tv <tv> 3.14.6-3.mga5
+ Revision: 689528
- fix excludes
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sat Jul 05 2014 pterjan <pterjan> 3.14.6-2.mga5
+ Revision: 643685
- Replace libusb*-devel BuildRequires by better ones

  + dtux <dtux>
    - change to version 3.14.6 of hplip
    - patch 103 : hplip-ui-optional.patch fixed upstream
    - patch 106 : hplip-mucks-with-spooldir.patch fixed upstream
    - patch 124 : hplip-addprinter.patch fixed upstream
    - patch 130 : hplip-hpaio-localonly.patch fixed upstream
    - patch 134 : hplip-mkstemp.patch fixed upstream
    - patch 205 : hplip-3.12.4-mga-87_move_documentation.dpatch fixed upstream
    - patch 213 : hp-mkuri-take-into-account-already-installed-plugin-also-for-exit-value.dpatch fixed upstream
    - patch 221 : hp-mkuri-libnotify-so-4-support.dpatch fixed upstream
    - patch 500 : hplip-CVE-2013-4325.patch fixed upstream
    - patch 501 : hplip-3.13.9-mga-CVE-2013-6402.patch fixed upstream
    - hplip-apply-udev-rules-on-action-change.patch modified
    - hplip-discovery-method.patch modified
    - hplip-hpijs-marker-supply.patch modified
    - hplip-logdir.patch modified some patches fixed upstream
    - hplip-udev-rules.patch modified
    - try_libhpmud.so.0.dpatch some patch fixed upstream

* Wed Jan 22 2014 doktor5000 <doktor5000> 3.13.9-4.mga4
+ Revision: 567495
- changed Patch501 to fix CVE-2013-6402 (mga#11809)
  o use Ubuntu patch backported from hplip-3.14.1 upstream fix

* Mon Jan 06 2014 doktor5000 <doktor5000> 3.13.9-3.mga4
+ Revision: 565216
- add Patch501 to fix CVE-2013-6402 (mga#11809)
  o fixes insecure hardcoded logfile name /tmp/hp-pkservice.log in pkit.py
- remove all upgrade-dialog files, not only the upgrade binary
  o more thorough fix for CVE-2013-6427
- added Requires on usbutils for lsusb, required for hp-check

* Tue Oct 22 2013 umeabot <umeabot> 3.13.9-2.mga4
+ Revision: 541678
- Mageia 4 Mass Rebuild

* Sun Oct 13 2013 doktor5000 <doktor5000> 3.13.9-1.mga4
+ Revision: 496333
- new version 3.13.9
  o lp#1209339  - HP OfficeJet G55 is not detecting through USB
  o Added support for print queue addition using hostname(hp-setup <HOSTNAME>)
  o Fix for plugin installation and test page in 'hp-setup -i'
- updated hplip-logdir.patch (from Fedora)
- updated hplip-no-asm.patch (from Fedora)
- removed the following patches (from Fedora), merged upstream with 3.13.9
  o hplip-IEEE-1284-4.patch
  o hplip-UnicodeDecodeError.patch
  o hplip-dbglog-newline.patch
  o hplip-dbus-exception.patch
  o hplip-notification-exception.patch
  o hplip-raw_deviceID-traceback.patch
  o hplip-skip-blank-lines.patch
  o hplip-systray-dbus-exception.patch
- removed the following patches (from Debian), merged upstream with 3.13.9
  o 10_shebang_fixes.dpatch
  o make-commafy-correctly-work-with-python-2.dpatch
- removed the following patches (from OpenSuse), merged upstream with 3.13.9
  o fix-uninitialized-variables.patch

* Sun Oct 13 2013 doktor5000 <doktor5000> 3.13.8-1.mga4
+ Revision: 496323
- new version 3.13.8
  o lp#233393  - Smart install disable popup is coming for HP pen drive and
    HP CD/DVD ROM
  o Added support for Avahi network printer browsing
  o Using SLP protocol by default to browse printer in hp-setup

* Sun Oct 13 2013 doktor5000 <doktor5000> 3.13.7-1.mga4
+ Revision: 496317
- new version 3.13.7
  o lp#746814  - CVE-2010-4267 Remote Stack Overflow Vulnerability
  o lp#1195221 - Unable to install plugin for network printer Laserjet 2600n
  o lp#1197306 - HP laserjet 1020 not printing on Ubuntu12.10 after power cycle
    the printer
  o lp#1196335 - HPLIP 3.13.6 stop working after shutting down/rebooting the
    computer
  o Unable to launch "Align Cartrides" and "Clean Cartridges" interfaces
    from HP Device Manager
- removed hplip-CVE-2010-4267.patch, integrated upstream

* Sun Oct 13 2013 doktor5000 <doktor5000> 3.13.6-1.mga4
+ Revision: 496307
- new version 3.13.6
  o lp#1186411 - Fix for firmware download during plug and play
  o added support for CUPS 1.6 IPP Private Structure changes
- added hplip-mkstemp.patch (from Fedora), avoids several bugs in
  createTempFile function (RH#925032)
- updated hplip-udev-rules.patch (from Fedora)
- removed cron config /etc/cron.daily/hplip_cron, merged upstream into
  /usr/share/hplip/hplip_clean.sh

* Sun Oct 13 2013 doktor5000 <doktor5000> 3.13.5-1.mga4
+ Revision: 496299
- new version 3.13.5
  o bottom margin is not printing on 8.5x13in paper size for DeskJet 2050 J510
- added /var/run/hplip to hplip-tmpfiles.conf
- remove new Suse-specific hplip-printer@.service
- marked cron job file as config(noreplace) (Fedora)
- rediffed hplip-apply-udev-rules-on-action-change.patch as all but one
  rules files have been removed
- rediffed hplip-dbglog-newline.patch
- rediffed hplip-logdir.patch
 -rediffed hplip-udev-rules.patch, integrated fix from Fedora to not add a
  printer queue, just check plugin is installed
- new version 3.13.4
- updated hplip-dbglog-newline.patch
- updated hplip-logdir.patch (from Fedora) - moves hpfax pipe to /var/run/hplip
- updated hplip-snmp-quirks.patch
- added hp-mkuri-libnotify-so-4-support.dpatch (from Debian)
- removed hplip-ipp-accessors.patch, integrated upstream
- removed hplip-3.11.10-mga-remove-duplicate-entry-for-cp1700-in-drv-files.patch
- removed hp-setup-prompt-for-custom-PPD.dpatch

* Sun Oct 13 2013 colin <colin> 3.13.3-2.mga4
+ Revision: 496248
- Drop consolehelper support as polkit support should be built in.

* Sun Oct 13 2013 doktor5000 <doktor5000> 3.13.3-1.mga4
+ Revision: 496167
- new version 3.13.3
  o fixed lp#1131596 - Not able to install HP 3.13.2 plugin
- removed hplip-pillow.patch, integrated upstream
  lp#1099853 - Fix use of PIL (Python Imaging Library) to support Pillow

* Fri Sep 27 2013 doktor5000 <doktor5000> 3.13.2-1.mga4
+ Revision: 487888
- new version 3.13.2
  o hp-check-plugin command removed, hp-doctor command added
  o fixed lp#816763 - Wrong syslog facility for debug messages
- removed hplip-check.patch
- removed hplip-syslog-fix-debug-messages-to-error.dpatch, integrated upstream
- removed hplip-3.13.2-mga-kde4-kdesudo-support.patch
- rediffed hplip-3.13.2-mga-automake-fix-subdir-objects.patch
- rediffed hplip-3.13.2-mga-85_rebuild_python_ui.dpatch
- renamed mga-kde4-kdesudo-support.dpatch (from Debian) and rediffed to
  hplip-3.13.2-mga-kde4-kdesudo-support.patch
- updated hplip-IEEE-1284-4.patch (from Fedora)
- updated hplip-logdir.patch (from Fedora)
- updated try_libhpmud.so.0.dpatch (from Debian)
- added hplip-pillow.patch f. python imaging library (PIL) import (from Fedora)
- added Provides exceptions for private python extension libs
- removed old Obsoletes/Provides on foomatic-db-hpijs
- removed old Suggests for foomatic-db-hpijs, package does not exist anymore
  and foomatic-db does not contain PPDs for HP printers, only .xml sources

* Sun Sep 22 2013 colin <colin> 3.12.11-2.mga4
+ Revision: 483257
- Make polkit usage secure (mga#11260 CVE-2013-4325)

* Sun Jul 07 2013 doktor5000 <doktor5000> 3.12.11-1.mga4
+ Revision: 450888
- new version 3.12.11
  o various fixes for hp-check
- updated hplip-IEEE-1284-4.patch (from Fedora)
- updated hplip-snmp-quirks.patch (from Fedora)
- added hplip-ipp-accessors.patch, to build against cups >= 1.6 (from Fedora)
- added hplip-udev-rules.patch (from Fedora)
  moves udev rules to /lib/udev/rules.d
- added hplip-systray-dbus-exception.patch (from Fedora)
 "Catch DBusException in hp-systray (rh#746024)
- added hplip-ui-optional.patch (from Fedora)
  "Make utils.checkPyQtImport() look for the gui sub-package (rh#243273)
- added hplip-logdir.patch (from Fedora)
  fixes "CUPS filters should use TMPDIR when available" (rh#865603)
- added hplip-check.patch (from Fedora)
  "Various adjustments to make 'hp-check' run more smoothly" (lp#683007)

* Sun Jun 23 2013 doktor5000 <doktor5000> 3.12.10-1.mga4
+ Revision: 446031
- use autoreconf instead of calling libtoolize/aclocal/autoconf/automake
- added required files for autoreconf
- added AUTOMAKE_OPTIONS = subdir-objects for newer automake
  (hplip-3.12.10-mga-automake-fix-subdir-objects.patch)
- rediffed Patch204 (hplip-3.12.10-mga-85_rebuild_python_ui.dpatch)
- new version 3.12.10
  o fixes hp binary plugin installation to /var/lib/hp - (hplip#1048732)
  o fixes "Cannot scan resolution on a Photosmart C6380" (mga#7637)
- removed obsoleted patch131 for CVE-2013-0200, integrated upstream
- updated hplip-notification-exception.patch (from Fedora)
- added hplip-IEEE-1284-4.patch to support IEEE 1284.4 protocol over USB
  (from Fedora)
- added %%{_localstatedir}/log/hp/tmp directory to fix hp-sendfax (rh#859658)

* Sun Mar 24 2013 colin <colin> 3.12.9-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Thu Feb 21 2013 luigiwalser <luigiwalser> 3.12.9-5.mga3
+ Revision: 399787
- rediff patch from redhat to fix CVE-2013-0200

* Tue Jan 15 2013 colin <colin> 3.12.9-4.mga3
+ Revision: 388373
- Switch to tmpfiles
- Fix udev rules.d dir

* Sat Jan 12 2013 umeabot <umeabot> 3.12.9-3.mga3
+ Revision: 353282
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 colin <colin> 3.12.9-2.mga3
+ Revision: 333359
- Require acl for hp-check (mga#8125)

* Thu Sep 20 2012 doktor5000 <doktor5000> 3.12.9-1.mga3
+ Revision: 296427
- new version 3.12.9
  o Added logcapture tool. User can collect logs by running 'hp-logcapture'
    command for any issue in print/scan/fax functionality
  o Fixed incorrect PPD picking issue during auto-plugin
  o Device IO error occurs when configuring or perform Scan operation from toolbox with PhotoSmart 6510 Series
- updated hplip-addprinter.patch from Fedora
- rediffed hplip-syslog-fix-debug-messages-to-error.patch
- replaced hplip-3.12.9-mga-makefile-chgrp.patch with sed call
- removed hplip-fax-ppd.patch
- update file list, add empty log directory

* Wed Sep 19 2012 doktor5000 <doktor5000> 3.12.6-1.mga3
+ Revision: 296267
- new version 3.12.6
  o Added PIN to PRINT support for HP Color LaserJet CM4540 MFP
  o Supplies information refreshes now without hp-toolbox restart
  o Fix for multiple queues configured warning message
  o Added dynamic cartridge part number display support for LEDM devices
  o Enabled Low ink alert message display for LEDM devices
- added hpaio-option-duplex.diff from Debian
- rediffed hplip-apply-udev-rules-on-action-change.patch
- updated hplip-mucks-with-spooldir.patch, hplip-snmp-quirks.patch,
  hplip-clear-old-state-reasons.patch, hplip-dbglog-newline.patch from Fedora
- removed hp-check-groups.dpatch
- removed unstandard X-MandrivaLinux-CrossDesktop from .desktop file (mga#3629)
- remove unapplied patches: hplip-3.11.3-mdv-link, hp-check_debian,
  ubuntu-hp-mkuri-notification-text, add_missing_newline_for_error_log,
  hplip-udev-rules.patch
- readded /var/lib/hp/hplip.state to fix hplip-plugin installation (mga#5395)

* Sun Apr 29 2012 doktor5000 <doktor5000> 3.12.4-1.mga2
+ Revision: 234171
- new version 3.12.4
  o Print/Fax queues can now be analyzed by running "hp-diagnose-queues"
  o fixes some issues and duplex scanning support with newer AIO devices
  o fixes Wireless configuration using hp-wificonfig command for
    HP Deskjet 3000 J310 series and HP Deskjet 3050 J610 series
  o fixes the blurry printing issue on HP LaserJet CP1025 and CP1025nw
- rediffed makefile-chgrp.patch, 85_rebuild_python_ui.dpatch and
  87_move_documentation.dpatch
- added fix-uninitialized-variables.patch (from OpenSUSE)
- remove binaries to uninstall/upgrade hplip

* Thu Apr 05 2012 anssi <anssi> 3.12.2-3.mga2
+ Revision: 228566
- don't fail %%post if udevadm settle fails

* Mon Mar 26 2012 anssi <anssi> 3.12.2-2.mga2
+ Revision: 226536
- actually apply udev rules in %%post by not depending on ACTION=="add"
  in the udev rules, instead depend on ACTION!="remove"
  (apply-udev-rules-on-action-change.patch)
- wait for udev to settle in %%post

* Mon Feb 27 2012 doktor5000 <doktor5000> 3.12.2-1.mga2
+ Revision: 215696
- new version 3.12.2
  o fixes the issue of digital signature mismatch for the plugin download by
    switching off the cache while downloading the plugin from the server
- don't remove systray applet launcher anymore, enables systray applet function
- added hpfax-bug-function-used-before-importing-log.dpatch (from Debian)
- added hp-systray-make-menu-title-visible-in-sni-qt-indicator.dpatch
  (from Debian)
- added hp-systray-make-menu-appear-in-sni-qt-indicator-with-kde.dpatch
- removed hplip-no-system-tray.patch, integrated upstream (hplip#335662)
- removed cups-1.5.0-compatibility.dpatch, integrated upstream
- removed useless Requires on cupsddk-drivers (provided by cups)
- removed obsolete %%clean section and empty %%defattrs
- updated file list

* Tue Dec 20 2011 doktor5000 <doktor5000> 3.11.12-1.mga2
+ Revision: 184886
- new version 3.11.12
  o Auto-detection and installation of missing plug-ins added
  o fixes hpcups not respecting top margins (hplip#890684)
- added mga-makefile-chgrp.patch, recreated from makefile-chgrp.patch against
  Makefile.am because we reprocess that one (from Fedora)
- added hplip-hpaio-localonly.patch (from Fedora)
- updated clear-old-state-reasons.patch (from Fedora)
- updated dbglog-newline.patch (from Fedora)
- updated mucks-with-spooldir.patch (from Fedora)
- updated udev-rules.patch (from Fedora)
- rediffed syslog-fix-debug-messages-to-error.dpatch
- removed dbus-threads.patch, integrated upstream (hplip#693070)
- removed emit-SIGNAL.patch, integrated upstream (hplip#673964)
- removed fab-root-crash.patch, integrated upstream (hplip#674450)
- removed hpaio-segfault.patch, integrated upstream (hplip#689755)
- removed newline.patch, integrated in add_missing_newline_for_error_log.patch
  (from Ubuntu, #418053)
- removed mga-udev-rules-use-attrs-not-sysfs-and-hp-mkuri-call-fix.patch,
  integrated upstream (Ubuntu#491346)
- adapt comment to display correct patch numbers
- updated file list

* Fri Oct 14 2011 doktor5000 <doktor5000> 3.11.10-1.mga2
+ Revision: 155222
- new version 3.11.10
  o fixes ADF scans from HP Officejet 6500 models (hplip#803584,819709,730515)
- use filter foomatic-rip instead of foomatic-rip-hplip (from Mandriva)
- updated hpcups-update-ppds.sh script (from Fedora)
- rediffed mga-remove-duplicate-entry-for-cp1700-in-drv-files.patch and renamed
  to hplip-3.11.10-mga-remove-duplicate-entry-for-cp1700-in-drv-files.patch
- removed unapplied and unneeded black-stripes-on-pcl5c-printouts.dpatch
- remove copy-deviceids.py, deviceIDs-drv.patch and deviceIDs-ppd.patch
  to restore upstream behavior
- removed obsolete CVE-2011-2722.patch, integrated upstream (hplip#809904)
- removed hpcups-crash.patch, integrated upstream (hplip#839632)
- removed sane-crash.patch, integrated upstream (hplip#838785)
- removed more-user-friendly-choice-names-for-installed-cartridges.dpatch,
  integrated upstream (hplip#788761)
- removed large-sizes-borderless-on-photosmart-pro-b-series.dpatch,
  integrated upstream (hplip#787580)
- removed mdns-py-network-printer-search-key-error.dpatch,
  integrated upstream (hplip#519430)
- remove hp-check_debian.dpatch, not needed anymore
- upload missing commented-out cups-1.5.0-compatibility.dpatch
- fixed Patch101 (pstotiff-is-rubbish.patch) missing a "\" (mga#2816)
- added Patch113 (hplip-hpcups-crash.patch, from Fedora)
- added Patch123 (hplip-sane-crash.patch, from Fedora)
- added Patch224 (syslog-fix-debug-messages-to-error, from Debian)
- added Patch225 (cups-1.5.0-compatibility, from Debian)
- added Patch226 (mdns-py-network-printer-search-key-errors, from Debian)

* Sun Sep 04 2011 doktor5000 <doktor5000> 3.11.7-1.mga2
+ Revision: 138413
- remove empty %%postun for sane-hpaio subpackage
- disable simple-scan-as-default.patch for now, as it changes default scanning application
- new version 3.11.7
  o fixes upgrade from Mandriva
- fix CVE-2011-2722
- added Requires on wget to avoid misleading errors about network connectivity
- added comments why systray .desktop file needs to be removed
- added Device ID for HP LaserJet Professional P1606dn
- Re-create installed hpcups PPDs unconditionally (RH bug #712241)
- resync with Fedora patches
- resync with Debian/Ubuntu Patches, reordered/renamed patches like debian does
- removed color-value-underflow.patch, already integrated in 3.11.5
- removed hplip-hpinfo-query-without-cups-queue.patch, dropped by debian
- removed hplip-systray-longer-timeout-for-system-tray-start.dpatch, fedora patch does the same
- removed hplip-3.9.8-dlopen-libhpmud.patch, obsoleted by newer try_libhpmud.so.0.dpatch
- removed hplip-udev-rules.patch, patched only one file, replaced by rediffed
  mga-udev-rules-use-attrs-not-sysfs-and-hp-mkuri-call-fix.patch
- removed black-stripes-on-pcl5c-printouts.dpatch, fedora patch does the same
- removed add_missing_newline_for_error_log.dpatch, fedora patch does the same
- removed ubuntu-hp-mkuri-notification-text.dpatch, specific to ubuntu
- rediffed hp-mkuri-take-into-account-already-installed-plugin-also-for-exit-value.dpatch

  + guillomovitch <guillomovitch>
    - rebuild for latest net-snmp

* Wed Jun 15 2011 cjw <cjw> 3.11.3a-7.mga2
+ Revision: 106663
- add provides libsane-hpaio to sane backend (for #792)

* Wed Jun 15 2011 dmorgan <dmorgan> 3.11.3a-6.mga2
+ Revision: 106333
- Do not package .la files

* Sat May 21 2011 cjw <cjw> 3.11.3a-5.mga1
+ Revision: 100081
- release fix for wrong colors on photosmart printers (fixes #1272)

* Sun May 15 2011 cjw <cjw> 3.11.3a-4.mga1
+ Revision: 98895
- patch1: fix color value underflow in hpcups filter (for bug #1272)

* Sat May 07 2011 cjw <cjw> 3.11.3a-3.mga1
+ Revision: 95747
- add provides: sane-backends-hpaio on the sane module package
- make hplip depend on python-imaging and sane-backends-hpaio, so the hp-scan tool actually works (see bug #792)

* Tue Apr 26 2011 wally <wally> 3.11.3a-2.mga1
+ Revision: 91745
- fix desktop file name (mga#954)

* Thu Apr 14 2011 cjw <cjw> 3.11.3a-1.mga1
+ Revision: 85144
- new version 3.11.3a
- remove old conflicts

  + dmorgan <dmorgan>
    - Fix typo

* Thu Feb 10 2011 spuhler <spuhler> 3.11.1-1.mga1
+ Revision: 49623
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package hplip

